carte = [
	"                                                            ",
	"                                                            ",
	"     X       XXXX        XXX    XXXXX      XXXXX     XXXX   ",
	"    X X      X   X      X   X   X   XX     X         X      ",
	"    X X      X   X     X        X    X     X         X      ",
	"   X   X     XXXX      X        X    X     XXXXX     XXXX   ",
	"   XXXXX     X   X     X        X    X     X         X      ",
	"   X   X     X   X      X   X   X   XX     X         X      ",
	"  X     X    XXXX        XXX    XXXXX      XXXXX     X      ",
	"                                                            ",
	"                                                            ",
	"                          X        X       X   X      X     ",
	"   XXXX      X    X       X        X       X  X       X     ",
	"  XX   X     X    X       X        X       X X        X     ",
	"  X          X    X       X        X       XX         X     ",
	"  X  XXX     XXXXXX       X        X       X X        X     ",
	"  X    X     X    X       X        X       X  X       X     ",
	"  XX   X     X    X       X        X       X   X      XXXXX ",
	"   XXXX      X    X                X                        ",
	"                                 XX                         ",
	"                                                            ",
	"  X     X                                            XXXX   ",
	"  XX   XX    X    X    XXXX       XXXX     XXXX      X   X  ",
	"  XX   XX    XX   X   XX  XX      X   X   XX  XX     X   X  ",
	"  X X X X    X X  X   X    X      X   X   X    X     XXXX   ",
	"  X X X X    X X  X   X    X      XXXX    X    X     X  X   ",
	"  X  X  X    X  X X   X    X      X       X    X     X   X  ",
	"  X     X    X   XX   XX  XX      X       XX  X      X    X ",
	"             X    X    XXXX       X        XXX              ",
	"                                              X             ",
	"                                                            ",
	"     XXX              X    X            X   X   X           ",
	"    X   X    XXXXX    X    X    X     X X   X   X   XX  XX  ",
	"    X          X      X    X    X     X  X X X X     X  X   ",
	"     XXX       X      X    X     X   X   X X X X      XX    ",
	"        X      X      X    X     X   X   X X X X      XX    ",
	"    X   X      X      X    X      X X     X   X       XX    ",
	"     XXX       X       XXXX       X X     X   X      X  X   ",
	"               X                   X                XX  XX  ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"   X     X   XXXXXX                                         ",
	"    X   X        X                                          ",
	"     X X        X                                           ",
	"      X        XX                                           ",
	"      X        X                                            ",
	"      X       X                                             ",
	"      X      XXXXXX                                         ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            ",
	"                                                            "
]
